import React from 'react';
import { View, Dimensions, StyleSheet } from 'react-native';
import { Svg } from 'react-native-svg';
import { Easing, runOnJS, useSharedValue, withRepeat, withTiming } from 'react-native-reanimated';
import AnimatedStroke from './AnimatedStroke';
import PlaceholderStroke from './PlaceholderStroke';

const AnimatedLogo = ({
  margin,
  paths,
  vWidth,
  vHeight,
  duration,
  strokeWidth,
  strokeColor,
  animatedStrokeColor,
  isRepeat = false,
  isAnimationFinished
}) => {
  const width = Dimensions.get('window').width - 64;
  const height = (width * vHeight + margin) / (vWidth + margin);
  const progress = useSharedValue(0);

  const animationFinished = isFinished => {
    if (isRepeat === false) {
      isAnimationFinished === null || isAnimationFinished === void 0 ? void 0 : isAnimationFinished(isFinished);
    }
  };

  React.useEffect(() => {
    progress.value = isRepeat ? withRepeat(withTiming(1, {
      duration,
      easing: Easing.inOut(Easing.ease)
    }), -1, true) : withTiming(1, {
      duration,
      easing: Easing.inOut(Easing.ease)
    }, () => {
      runOnJS(animationFinished)(true);
    }); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [progress]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(View, {
    style: styles.layer
  }, /*#__PURE__*/React.createElement(Svg, {
    width: width,
    height: height,
    viewBox: "".concat(-margin / 2, " ").concat(-margin / 2, " ").concat(vWidth + margin / 2, " ").concat(vHeight + margin / 2)
  }, paths.map((d, key) => /*#__PURE__*/React.createElement(AnimatedStroke, {
    d: d,
    strokeWidth: strokeWidth,
    animatedStrokeColor: animatedStrokeColor,
    progress: progress,
    key: key
  })))), /*#__PURE__*/React.createElement(View, {
    style: [styles.layer, {
      opacity: 0.2
    }]
  }, /*#__PURE__*/React.createElement(Svg, {
    width: width,
    height: height,
    viewBox: "".concat(-margin / 2, " ").concat(-margin / 2, " ").concat(vWidth + margin / 2, " ").concat(vHeight + margin / 2)
  }, paths.map((d, key) => /*#__PURE__*/React.createElement(PlaceholderStroke, {
    key: key,
    d: d,
    strokeWidth: strokeWidth,
    strokeColor: strokeColor
  })))));
};

export default AnimatedLogo;
const styles = StyleSheet.create({
  layer: { ...StyleSheet.absoluteFillObject,
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  }
});
//# sourceMappingURL=AnimatedLogo.js.map